diff --git a/polkadot/runtime/kusama/src/lib.rs b/polkadot/runtime/kusama/src/lib.rs
index 494d5590d94127a7cb13f47d2a7f412281b7d2d9..437b705e4247a99c5fdc55c1e250e01b0260d72a 100644
--- a/polkadot/runtime/kusama/src/lib.rs
+++ b/polkadot/runtime/kusama/src/lib.rs
@@ -405,13 +405,11 @@ parameter_types! {
 
 	// 1 hour session, 15 minutes unsigned phase, 8 offchain executions.
 	pub OffchainRepeat: BlockNumber = UnsignedPhase::get() / 8;
-
-	/// We take the top 22_500 nominators as electing voters..
-	pub const MaxElectingVoters: u32 = 22_500;
+	/// We take the top 12_500 nominators as electing voters..
+	pub const MaxElectingVoters: u32 = 12_500;
 	/// ... and all of the validators as electable targets. Whilst this is the case, we cannot and
 	/// shall not increase the size of the validator intentions.
 	pub const MaxElectableTargets: u16 = u16::MAX;
-
 }
 
 frame_election_provider_support::generate_solution_type!(